/*jshint -W082 */
'use strict';

exports.__esModule = true;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _htmlparser2 = require('htmlparser2');

var _htmlparser22 = _interopRequireDefault(_htmlparser2);

function toTree(html) {

    var bufArray = [],
        results = [];

    bufArray.last = function () {
        return this[this.length - 1];
    };

    var parser = new _htmlparser22['default'].Parser({
        onprocessinginstruction: function onprocessinginstruction(name, data) {
            name === '!doctype' && results.push('<' + data + '>');
        },
        oncomment: function oncomment(data) {
            var comment = '<!-- ' + data.trim() + ' -->',
                last = bufArray.last();

            if (!last) {
                results.push(comment);
                return;
            }

            last.content || (last.content = []);
            last.content.push(comment);
        },
        onopentag: function onopentag(tag, attrs) {
            var buf = {};

            buf.tag = tag;

            if (!isEmpty(attrs)) buf.attrs = attrs;

            if (isEmpty(buf)) buf = { content: '' };

            bufArray.push(buf);
        },
        onclosetag: function onclosetag() {
            var buf = bufArray.pop();

            if (bufArray.length === 0) {
                results.push(buf);

                return;
            }

            var last = bufArray.last();
            if (!(last.content instanceof Array)) {
                last.content = [];
            }
            last.content.push(buf);
        },
        ontext: function ontext(text) {
            var last = bufArray.last();
            if (!last) {
                results.push(text);
                return;
            }

            last.content || (last.content = []);
            last.content.push(text);
        }
    });

    parser.write(html);
    parser.end();

    return results;
}

exports['default'] = {
    toTree: toTree
};

function isEmpty(obj) {
    for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
            return false;
        }
    }

    return true;
}
module.exports = exports['default'];